==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Indstillinger for Udseende</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt Tema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="44"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Indstillinger for Udseende</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>Widget Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="54"/>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="58"/>
        <source>LXQt Theme</source>
        <translation>LXQt Tema</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="62"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Cursor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.11.2.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Standardskrifttype til brugerflade</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Skrifttypenavn:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>Punktstørrelse:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>Fed kursiv</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Følgende indstillinger påvirker kun nyligt startet programmer</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Brug antialias-skrifttyper</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>Skrifttype hinting-stil:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>Let</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>Fuld</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>Skrifttype hintning</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>Opløsning (DPI):</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>Autohint</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>Underpixel-antialiasing:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Konfiguraton af LXQt udseende</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="44"/>
        <source>LXQt Appearance Configuration</source>
        <translation>Konfiguraton af LXQt udseende</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>Widget Style</source>
        <translation>Widget-stil</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="54"/>
        <source>Icons Theme</source>
        <translation>Ikontema</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="58"/>
        <source>LXQt Theme</source>
        <translation>LXQt-tema</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="62"/>
        <source>Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Cursor</source>
        <translation>Markør</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>Widget-stil</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation>Værktøjslinje knap-stil:</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation>Vis kun ikonet</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation>Vis kun teksten</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation>Teksten vises ved siden af ikonet</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation>Teksten vises under ikonet</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation>Aktivér objekt med ét klik</translation>
    </message>
</context>
</TS>
